==> banshee-1-1.5.2.tar.gz: banshee-1-1.5.2/src/Core/Banshee.Services/Banshee.PlaybackController/IPlaybackControllerService.cs <==
//
// IPlaybackControllerExportable.cs
//
// Author:
//   Aaron Bockover <abockover@novell.com>
//
// Copyright (C) 2007-2008 Novell, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using NDesk.DBus;

using Banshee.ServiceStack;

namespace Banshee.PlaybackController
{
    public delegate void PlaybackControllerStoppedHandler ();

    [Interface ("org.bansheeproject.Banshee.PlaybackController")]
    public interface IPlaybackControllerService : IDBusExportable
    {
        // FIXME: IPlaybackControllerExportable : IPlaybackController
        // but NDesk DBus has a design flaw where it only exports
        // members of the top level interface where the [Interface]
        // attribute is applied

        event PlaybackControllerStoppedHandler Stopped;

        void First ();
        void Next (bool restart);
        void Previous (bool restart);

        PlaybackShuffleMode ShuffleMode { get; set; }
        PlaybackRepeatMode RepeatMode { get; set; }
        bool StopWhenFinished { get; set; }
    }
}

==> banshee-1-1.5.6.tar.gz: banshee-1-1.5.6/src/Core/Banshee.Services/Banshee.PlaybackController/IPlaybackControllerService.cs <==
//
// IPlaybackControllerExportable.cs
//
// Author:
//   Aaron Bockover <abockover@novell.com>
//
// Copyright (C) 2007-2008 Novell, Inc.
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
//
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using NDesk.DBus;

using Banshee.ServiceStack;

namespace Banshee.PlaybackController
{
    public delegate void PlaybackControllerStoppedHandler ();

    [Interface ("org.bansheeproject.Banshee.PlaybackController")]
    public interface IPlaybackControllerService : IDBusExportable
    {
        // FIXME: IPlaybackControllerExportable : IPlaybackController
        // but NDesk DBus has a design flaw where it only exports
        // members of the top level interface where the [Interface]
        // attribute is applied

        event PlaybackControllerStoppedHandler Stopped;

        void First ();
        void Next (bool restart);
        void Previous (bool restart);
        void RestartOrPrevious (bool restart);

        string ShuffleMode { get; set; }
        PlaybackRepeatMode RepeatMode { get; set; }
        bool StopWhenFinished { get; set; }
    }
}
